@@ -8,7 +8,7 @@
 
 
 from detector_connector.detector_connector import DetectorConnector
-from detector_connector.detector_http_connector import DetectorHttpConnector, DetectorSettingsType
+from detector_connector.detector_http_connector import DetectorHttpConnector, DetectorSettings
 from detector_connector.detector_kafka_connector import (DetectorKafkaConnector,
-                                                         DetectionAnalyzeResultType,
+                                                         DetectorAnalyzeResult,
                                                          AnalyzeResultCallback)
