@@ -8,9 +8,10 @@
 
 
 from dataclasses import dataclass
+from typing import Type
 
-from detector_connector.detector_http_connector import DetectorHttpConnector, DetectorSettingsType
-from detector_connector.detector_kafka_connector import DetectorKafkaConnector, DetectionAnalyzeResultType
+from detector_connector.detector_http_connector import DetectorHttpConnector, DetectorSettings
+from detector_connector.detector_kafka_connector import DetectorKafkaConnector, DetectorAnalyzeResult
 
 
 class DetectorConnector:
@@ -25,8 +26,8 @@ class DetectorConnector:
     def __init__(self,
                  config: Config,
                  context: Context,
-                 detector_analyze_result_type: DetectionAnalyzeResultType,
-                 detector_settings_type: DetectorSettingsType) -> None:
+                 detector_analyze_result_type: Type[DetectorAnalyzeResult],
+                 detector_settings_type: Type[DetectorSettings]) -> None:
         self.http_connector = DetectorHttpConnector(config=config,
                                                     context=context,
                                                     detector_settings_type=detector_settings_type)
