@@ -16,12 +16,27 @@ from aiokafka import ConsumerRecord
 
 from kafka_tools.kafka_client.consumer import Consumer
 from kafka_tools.kafka_client.producer import Producer
-from init_helpers.dict_to_dataclass import dict_to_dataclass, T
+from init_helpers.dict_to_dataclass import dict_to_dataclass
 
 
 logger = logging.getLogger(__name__)
-DetectionAnalyzeResultType = Type[T]
-AnalyzeResultCallback = Callable[[DetectionAnalyzeResultType], Awaitable[Any]]
+
+
+@dataclass
+class DetectorAnalyzeResult:
+    rtsp_url: str
+    snapshot_file_id: str
+    snapshot_done_at: float
+    reference_image_file_ids: list[str]
+    detector_requests: list[dict[str, str | float | bool | int]]
+    detector_results: list[dict[str, str | float | bool | int]]
+    comparison_settings: dict[str, str | float | list]
+    comparison_results: list[float]
+    result: float
+    analyzed_at: float
+
+
+AnalyzeResultCallback = Callable[[DetectorAnalyzeResult], Awaitable[Any]]
 
 
 class DetectorKafkaConnector:
@@ -38,7 +53,7 @@ class DetectorKafkaConnector:
     def __init__(self,
                  config: Config,
                  context: Context,
-                 detector_analyze_result_type: DetectionAnalyzeResultType) -> None:
+                 detector_analyze_result_type: Type[DetectorAnalyzeResult]) -> None:
         self.config = config
         self.context = context
         self.detector_analyze_result_type = detector_analyze_result_type
@@ -62,6 +77,6 @@ class DetectorKafkaConnector:
             await callback(analyze_result)
         await self.context.kafka_consumer.commit(record)
 
-    def _deserialize_analyze_result(self, record: ConsumerRecord) -> T:
+    def _deserialize_analyze_result(self, record: ConsumerRecord) -> DetectorAnalyzeResult:
         payload = json.loads(record.value)
         return dict_to_dataclass(payload, self.detector_analyze_result_type)
